Python Module for APRS-IS.

.. image:: https://travis-ci.org/ampledata/aprs.png?branch=develop
        :target: https://travis-ci.org/ampledata/aprs

Source
======
Github: https://github.com/ampledata/aprs

Author
======
Greg Albrecht W2GMD <gba@gregalbrecht.com>

Copyright
=========
Copyright 2013 Greg Albrecht

License
=======
Creative Commons Attribution 3.0 Unported License
